@@ -1,8 +1,8 @@
 # $File: //depot/cpan/Module-Install/lib/Module/Install.pm $ $Author: autrijus $
-# $Revision: #56 $ $Change: 1647 $ $DateTime: 2003/07/16 01:07:55 $ vim: expandtab shiftwidth=4
+# $Revision: #57 $ $Change: 1666 $ $DateTime: 2003/08/18 08:00:18 $ vim: expandtab shiftwidth=4
 
 package Module::Install;
-$VERSION = '0.22';
+$VERSION = '0.23';
 
 die <<END unless defined $INC{'inc/Module/Install.pm'};
 You must invoke Module::Install with:
@@ -27,8 +27,8 @@ Module::Install - Standalone, extensible Perl module installer
 
 =head1 VERSION
 
-This document describes version 0.22 of Module::Install, released
-July 16, 2003.
+This document describes version 0.23 of Module::Install, released
+August 18, 2003.
 
 =head1 SYNOPSIS
 
